From 623c6a3bb7390ab5c67768e5509b82daa1f377c7 Mon Sep 17 00:00:00 2001
From: epic morphism <epicmorphism@tilde.town>
Date: Thu, 2 May 2019 17:53:47 +0000
Subject: [PATCH] add glyphs for spaces

---
 tdfiglet.c | 34 ++++++++++++++++++++++++++++++----
 1 file changed, 30 insertions(+), 4 deletions(-)

diff --git a/tdfiglet.c b/tdfiglet.c
index ae7352d..ad6a229 100644
--- a/tdfiglet.c
+++ b/tdfiglet.c
@@ -118,6 +118,7 @@ void readchar(int i, glyph_t *glyph, font_t *font);
 void ibmtoutf8(char *a, char *u);
 void printcolor(uint8_t color);
 int lookupchar(char c, const font_t *font);
+glyph_t *empty_glyph(int width, int height);
 
 void printcell(char *utfchar, uint8_t color);
 void printrow(const glyph_t *glyph, int row);
@@ -500,6 +501,26 @@ lookupchar(char c, const font_t *font)
 	return -1;
 }
 
+glyph_t 
+*empty_glyph (int width, int height)
+{
+  glyph_t * glyph = calloc(1, sizeof(glyph_t));
+  glyph->width = width;
+  glyph->height = height;
+
+  glyph->cell = calloc(width * height, sizeof(cell_t));
+  if (!glyph->cell) {
+    perror(NULL);
+    exit(EX_OSERR);
+  }
+
+  for (int i = 0; i < width * height; i++) {
+    glyph->cell[i].utfchar[0] = ' ';
+    glyph->cell[i].color = 0;
+  }
+  return glyph;
+}
+
 void
 ibmtoutf8(char *a, char *u)
 {
@@ -573,6 +594,7 @@ void
 printstr(const char *str, font_t *font)
 {
 	int maxheight = 0;
+	int maxwidth = 0;
 	int linewidth = 0;
 	int len = strlen(str);
 	int padding = 0;
@@ -592,6 +614,9 @@ printstr(const char *str, font_t *font)
 		if (g->height > maxheight) {
 			maxheight = g->height;
 		}
+		if (g->width > maxwidth) {
+			maxwidth = g->width;
+		}
 
 		linewidth += g->width;
 		if (linewidth + 1 < len) {
@@ -612,12 +637,13 @@ printstr(const char *str, font_t *font)
 
 		for (int c = 0; c < strlen(str); c++) {
 			n = lookupchar(str[c], font);
-
+			glyph_t *g = NULL;
+			
 			if (n == -1) {
-				continue;
+			        g = empty_glyph(maxwidth, maxheight);
+			} else {
+			        g = font->glyphs[n];
 			}
-
-			glyph_t *g = font->glyphs[n];
 			printrow(g, i);
 
 			if (opt.color == COLOR_ANSI) {
-- 
2.19.1

